@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # to run this script type:
 # zterm.py [prog [args ...]]
-# if no program name given, use the value of the environment variable SHELL.
+# if no program name given, spawm a python interpreter
 
 import sys
 if sys.version[:3] == '1.4':
@@ -14,6 +14,8 @@ def child_died_event(zvt):
 	sys.exit(0)
 
 def main():
+	font_name = "-misc-fixed-medium-r-normal--20-200-75-75-c-100-*-*"
+
 	win = GtkWindow()
 	win.connect("delete_event", mainquit)
 	win.set_title("ZTerm")
@@ -23,9 +25,9 @@ def main():
 	win.add(hbox)
 	hbox.show()
 	
-	term = ZvtTerm()
+	term = ZvtTerm(80, 25)
 	term.set_scrollback(50)
-	term.set_font_name("-misc-fixed-medium-r-normal--20-200-75-75-c-100-*-*")
+	term.set_font_name(font_name);
 	term.connect("child_died", child_died_event)
 	hbox.pack_start(term)
 	term.show()
@@ -33,7 +35,13 @@ def main():
 	scroll = GtkVScrollbar(term.adjustment)
 	hbox.pack_start(scroll, expand=FALSE)
 	scroll.show()
-	
+
+	charwidth = term.charwidth
+	charheight = term.charheight
+	win.set_geometry_hints(geometry_widget=term,
+			       min_width=2*charwidth, min_height=2*charheight,
+			       base_width=charwidth,  base_height=charheight,
+			       width_inc=charwidth,   height_inc=charheight)
 	win.show()
 
 	pid = term.forkpty()
@@ -45,9 +53,9 @@ def main():
 		if not argv:
 			os.execv('/usr/bin/env', ['/usr/bin/env', 'python'])
 		else:
-			os.execv(argv[0], argv)
+			os.execvp(argv[0], argv)
 		print "Couldn't exec"
-		sys.exit(1)
+		os._exit(1)
 	# this is executed by parent process only:
 	mainloop()
 
