@@ -410,6 +410,9 @@ class GnomeCanvasGroup(GnomeCanvasItem):
 	def new_item(self, tp, **args):
 		print "I renamed this func to GnomeCanvasGroup.add"
 		return apply(self.add, (tp,), args)
+	def children(self):
+		return map(_obj2inst, _gnomeui.gnome_canvas_group_children(
+			self._o))
 _gtk._name2cls['GnomeCanvasGroup'] = GnomeCanvasGroup
 
 class GnomeCanvasImage(GnomeCanvasItem):
@@ -829,9 +832,11 @@ class GnomeIconList(GnomeCanvas):
 	def set_selection_mode(self, mode):
 		_gnomeui.gnome_icon_list_set_selection_mode(self._o, mode)
 	def append(self, icon_filename, text):
-		_gnomeui.gnome_icon_list_append(self._o, icon_filename, text)
+		return _gnomeui.gnome_icon_list_append(self._o, icon_filename,
+						       text)
 	def append_imlib(self, image, text):
-		_gnomeui.gnome_icon_list_append_imlib(self._o, image._im, text)
+		return _gnomeui.gnome_icon_list_append_imlib(self._o,
+							     image._im, text)
 	def insert(self, pos, icon_filename, text):
 		_gnomeui.gnome_icon_list_insert(self._o, pos, icon_filename,
 						text)
@@ -866,13 +871,13 @@ class GnomeIconList(GnomeCanvas):
 	def set_icon_width(self, width):
 		_gnomeui.gnome_icon_list_set_icon_width(self._o, width)
 	def set_row_spacing(self, spacing):
-		_gnomeui.gnome_icon_list_set_row_spacing(self._o, pos, spacing)
+		_gnomeui.gnome_icon_list_set_row_spacing(self._o, spacing)
 	def set_col_spacing(self, spacing):
-		_gnomeui.gnome_icon_list_set_col_spacing(self._o, pos, spacing)
+		_gnomeui.gnome_icon_list_set_col_spacing(self._o, spacing)
 	def set_text_spacing(self, spacing):
-		_gnomeui.gnome_icon_list_set_text_spacing(self._o,pos,spacing)
+		_gnomeui.gnome_icon_list_set_text_spacing(self._o, spacing)
 	def set_icon_border(self, spacing):
-		_gnomeui.gnome_icon_list_set_icon_border(self._o, pos, spacing)
+		_gnomeui.gnome_icon_list_set_icon_border(self._o, spacing)
 	def set_separators(self, separators):
 		_gnomeui.gnome_icon_list_set_separators(self._o, separators)
 	def set_hadjustment(self, adj):
@@ -1120,13 +1125,13 @@ class GnomePixmap(_gtk.GtkWidget):
 				self._o = _gnomeui.gnome_pixmap_new_from_file_at_size(
 					filename, width, height)
 	def load_file(self, filename, width=-1, height=-1):
-		if (width, heigth) == (-1, -1):
+		if (width, height) == (-1, -1):
 			_gnomeui.gnome_pixmap_load_file(self._o, filename)
 		else:
 			_gnomeui.gnome_pixmap_load_file_at_size(self._o,
 						filename, width, height)
 	def load_imlib(self, image, width=-1, height=-1):
-		if (width, heigth) == (-1, -1):
+		if (width, height) == (-1, -1):
 			_gnomeui.gnome_pixmap_load_imlib(self._o, image._im)
 		else:
 			_gnomeui.gnome_pixmap_load_imlib_at_size(self._o,
@@ -1252,6 +1257,10 @@ def GnomeStockPixmapWidget(win, icon=None):
 	print "Deprecated -- use GnomeStock instead of GnomeStockPixmapWidget"
 	return GnomeStock(icon)
 
+class GnomePixmapButton(_gtk.GtkButton):
+	def __init__(self, pixmap, text, _obj=None):
+		self._o = _gnomeui.gnome_pixmap_button(pixmap._o, text)
+
 # these aren't really different types, but having different classes is easier
 class GnomeStockButton(_gtk.GtkButton):
 	def __init__(self, type):
